CodecRuntimeException class

Encoder/decoder is in an error state and must be closed/recreated.

Inheritance

Constructors

CodecRuntimeException(String backendName, String message, {Object? cause})
const

Properties

backendName String
final
cause Object?
final
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited