NoBackendForCodecException class
No registered backend can handle the requested codec / container.
- Inheritance
-
- Object
- MiniAVToolsException
- NoBackendForCodecException
Constructors
- NoBackendForCodecException.audio(AudioCodec c)
-
factory
- NoBackendForCodecException.container(Container c)
-
factory
- NoBackendForCodecException.video(VideoCodec c, {bool hwAccel = false})
-
factory
Properties
- audioCodec → AudioCodec?
-
final
- container → Container?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoCodec → VideoCodec?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited