StreamDemuxerInput class

A progressive/live container byte stream (fMP4 / MKV / MPEG-TS from the network, a recorder chunk stream, …).

The backend buffers up to bufferBytes of undemuxed input and applies backpressure to stream (pause/resume) when the demuxer falls behind. Non-seekable. Note: plain (non-fragmented) MP4 needs its moov atom up-front (faststart / fMP4) to be demuxable as a stream.

Inheritance

Constructors

StreamDemuxerInput(Stream<List<int>> stream, {int bufferBytes = 16 * 1024 * 1024})
const

Properties

bufferBytes int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<List<int>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited