isSharedBuffer function
Whether buffer is memory two threads can genuinely share. Never, off-web.
Implementation
bool isSharedBuffer(ByteBuffer buffer) => false;
Whether buffer is memory two threads can genuinely share. Never, off-web.
bool isSharedBuffer(ByteBuffer buffer) => false;