stop method
Stop recording and wait for the final chunk to be delivered.
Implementation
Future<void> stop() async {
final rec = _recorder;
if (rec == null) return;
_recorder = null;
rec.stop();
await _completer.future;
}
Stop recording and wait for the final chunk to be delivered.
Future<void> stop() async {
final rec = _recorder;
if (rec == null) return;
_recorder = null;
rec.stop();
await _completer.future;
}