kRoleVideo top-level constant
String
const kRoleVideo
Role of a codec worker, chosen by the host in the initial message.
Implementation
const String kRoleVideo = 'video';
Role of a codec worker, chosen by the host in the initial message.
const String kRoleVideo = 'video';