EncoderLevel enum
H.264 / HEVC level. Backends interpret this codec-appropriately.
Values
- level3_0 → const EncoderLevel
- level3_1 → const EncoderLevel
- level4_0 → const EncoderLevel
- level4_1 → const EncoderLevel
- level5_0 → const EncoderLevel
- level5_1 → const EncoderLevel
- level5_2 → const EncoderLevel
- level6_0 → const EncoderLevel
- level6_1 → const EncoderLevel
- level6_2 → const EncoderLevel
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EncoderLevel> - A constant List of the values in this enum, in order of their declaration.