MuxerConfig class
Configuration for a muxer (encoded packets → container file/stream).
Constructors
-
MuxerConfig({required Container container, required MuxerOutput output, required List<
TrackInfo> tracks, int fragmentDurationUs = 0, Map<String, String> backendOptions = const {}}) -
const
Properties
-
backendOptions
→ Map<
String, String> -
final
- container → Container
-
final
- fragmentDurationUs → int
-
For fragmented MP4 etc.: target fragment duration in microseconds.
0 = container default.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- output → MuxerOutput
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tracks
→ List<
TrackInfo> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited